
#line 1 "source/parser/TextFileParser.rl"
#include "parser/TextFile.h"
#include "Color.h"
#include <string.h>
#include <stdlib.h>
#include <cstddef>
#include <functional>
#include <vector>
#include <string>
#include <iostream>
using namespace std;

namespace text_file_parser {

class FSM
{
	public:
		int cs;
		char separator;
		int act;
		int top;
		char *ts;
		char *te;
		int stack[256];
		char buffer[8 * 1024];
		int line;
		int column;
		int line_start;
		int buffer_offset;
		int64_t number_i64;
		vector<int64_t> numbers_i64;
		char *number_double_start;
		vector<double> numbers_double;
		function<void(const Color&)> addColor;
		void handleNewline()
		{
			line++;
			column = 0;
			line_start = te - buffer;
		}
		int hexToInt(char hex)
		{
			if (hex >= '0' && hex <= '9') return hex - '0';
			if (hex >= 'a' && hex <= 'f') return hex - 'a' + 10;
			if (hex >= 'A' && hex <= 'F') return hex - 'A' + 10;
			return 0;
		}
		int hexPairToInt(const char *hex_pair)
		{
			return hexToInt(hex_pair[0]) << 4 | hexToInt(hex_pair[1]);
		}
		void colorHexFull(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexPairToInt(ts + start_index) / 255.0;
			color.rgb.green = hexPairToInt(ts + start_index + 2) / 255.0;
			color.rgb.blue = hexPairToInt(ts + start_index + 4) / 255.0;
			addColor(color);
		}
		void colorHexShort(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexToInt(ts[start_index + 0]) / 15.0;
			color.rgb.green = hexToInt(ts[start_index + 1]) / 15.0;
			color.rgb.blue = hexToInt(ts[start_index + 2]) / 15.0;
			color.ma[3] = 0;
			addColor(color);
		}
		void colorRgb()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		void colorRgba()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = numbers_double[0];
			numbers_i64.clear();
			numbers_double.clear();
			addColor(color);
		}
		void colorValues()
		{
			Color color;
			color.rgb.red = numbers_double[0];
			color.rgb.green = numbers_double[1];
			color.rgb.blue = numbers_double[2];
			color.ma[3] = 0;
			numbers_double.clear();
			addColor(color);
		}
		void colorValueIntegers()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0;
			color.rgb.green = numbers_i64[1] / 255.0;
			color.rgb.blue = numbers_i64[2] / 255.0;
			color.ma[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		double parseDouble(const char *start, const char *end)
		{
			string v(start, end);
			return stod(v.c_str());
		}
		void clearNumberStacks()
		{
			numbers_i64.clear();
			numbers_double.clear();
		}
};



#line 156 "source/parser/TextFileParser.rl"



#line 132 "build/source/parser/TextFileParser.cpp"
static const char _text_file_trans_keys[] = {
	0, 0, 48, 102, 48, 102, 48, 102, 48, 102, 9, 101, 9, 44, 9, 57, 
	46, 57, 48, 57, 9, 101, 9, 44, 9, 57, 46, 57, 48, 57, 43, 57, 
	48, 57, 43, 57, 48, 57, 9, 57, 9, 101, 43, 57, 48, 57, 9, 57, 
	9, 101, 48, 57, 9, 57, 9, 57, 9, 101, 9, 44, 9, 57, 9, 57, 
	9, 57, 9, 57, 9, 57, 9, 44, 9, 57, 9, 57, 9, 44, 9, 57, 
	9, 57, 9, 41, 9, 57, 9, 57, 9, 44, 9, 57, 9, 57, 9, 44, 
	9, 57, 9, 57, 9, 44, 9, 57, 46, 57, 48, 57, 9, 101, 9, 41, 
	43, 57, 48, 57, 9, 57, 9, 101, 10, 42, 10, 47, 10, 10, 9, 126, 
	9, 126, 9, 32, 9, 32, 33, 126, 33, 126, 48, 102, 33, 126, 33, 126, 
	48, 101, 48, 57, 46, 101, 33, 126, 9, 126, 46, 101, 48, 57, 9, 126, 
	9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 
	9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 
	9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 9, 126, 0, 0, 0, 0, 
	0
};

static const char _text_file_key_spans[] = {
	0, 55, 55, 55, 55, 93, 36, 49, 
	12, 10, 93, 36, 49, 12, 10, 15, 
	10, 15, 10, 49, 93, 15, 10, 49, 
	93, 10, 49, 49, 93, 36, 49, 49, 
	49, 49, 49, 36, 49, 49, 36, 49, 
	49, 33, 49, 49, 36, 49, 49, 36, 
	49, 49, 36, 49, 12, 10, 93, 33, 
	15, 10, 49, 93, 33, 38, 1, 118, 
	118, 24, 24, 94, 94, 55, 94, 94, 
	54, 10, 56, 94, 118, 56, 10, 118, 
	118, 118, 118, 118, 118, 118, 118, 118, 
	118, 118, 118, 118, 118, 118, 118, 118, 
	118, 118, 118, 118, 118, 118, 0, 0
};

static const short _text_file_index_offsets[] = {
	0, 0, 56, 112, 168, 224, 318, 355, 
	405, 418, 429, 523, 560, 610, 623, 634, 
	650, 661, 677, 688, 738, 832, 848, 859, 
	909, 1003, 1014, 1064, 1114, 1208, 1245, 1295, 
	1345, 1395, 1445, 1495, 1532, 1582, 1632, 1669, 
	1719, 1769, 1803, 1853, 1903, 1940, 1990, 2040, 
	2077, 2127, 2177, 2214, 2264, 2277, 2288, 2382, 
	2416, 2432, 2443, 2493, 2587, 2621, 2660, 2662, 
	2781, 2900, 2925, 2950, 3045, 3140, 3196, 3291, 
	3386, 3441, 3452, 3509, 3604, 3723, 3780, 3791, 
	3910, 4029, 4148, 4267, 4386, 4505, 4624, 4743, 
	4862, 4981, 5100, 5219, 5338, 5457, 5576, 5695, 
	5814, 5933, 6052, 6171, 6290, 6409, 6528, 6529
};

static const unsigned char _text_file_indicies[] = {
	1, 1, 1, 1, 1, 1, 1, 
	1, 1, 1, 0, 0, 0, 0, 0, 
	0, 0, 1, 1, 1, 1, 1, 1, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 1, 1, 1, 1, 1, 1, 
	0, 2, 2, 2, 2, 2, 2, 2, 
	2, 2, 2, 0, 0, 0, 0, 0, 
	0, 0, 2, 2, 2, 2, 2, 2, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 2, 2, 2, 2, 2, 2, 
	0, 4, 4, 4, 4, 4, 4, 4, 
	4, 4, 4, 3, 3, 3, 3, 3, 
	3, 3, 4, 4, 4, 4, 4, 4, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 4, 4, 4, 4, 4, 4, 
	3, 5, 5, 5, 5, 5, 5, 5, 
	5, 5, 5, 3, 3, 3, 3, 3, 
	3, 3, 5, 5, 5, 5, 5, 5, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 3, 3, 3, 3, 3, 3, 
	3, 3, 5, 5, 5, 5, 5, 5, 
	3, 7, 7, 7, 7, 7, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	7, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 8, 6, 6, 6, 
	9, 9, 9, 9, 9, 9, 9, 9, 
	9, 9, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 10, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 10, 6, 11, 
	11, 11, 11, 11, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 11, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 12, 6, 12, 12, 12, 12, 
	12, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 12, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 13, 6, 
	13, 14, 6, 15, 15, 15, 15, 15, 
	15, 15, 15, 15, 15, 6, 16, 6, 
	17, 17, 17, 17, 17, 17, 17, 17, 
	17, 17, 6, 18, 18, 18, 18, 18, 
	18, 18, 18, 18, 18, 6, 19, 19, 
	19, 19, 19, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 19, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 20, 6, 6, 6, 18, 18, 18, 
	18, 18, 18, 18, 18, 18, 18, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 21, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 21, 6, 22, 22, 22, 22, 
	22, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 22, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 23, 
	6, 23, 23, 23, 23, 23, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	23, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 24, 6, 24, 25, 6, 
	26, 26, 26, 26, 26, 26, 26, 26, 
	26, 26, 6, 27, 6, 28, 28, 28, 
	28, 28, 28, 28, 28, 28, 28, 6, 
	29, 29, 29, 29, 29, 29, 29, 29, 
	29, 29, 6, 30, 6, 30, 6, 6, 
	31, 31, 31, 31, 31, 31, 31, 31, 
	31, 31, 6, 31, 31, 31, 31, 31, 
	31, 31, 31, 31, 31, 6, 32, 6, 
	32, 6, 6, 33, 33, 33, 33, 33, 
	33, 33, 33, 33, 33, 6, 33, 33, 
	33, 33, 33, 33, 33, 33, 33, 33, 
	6, 19, 19, 19, 19, 19, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	19, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 20, 6, 6, 6, 
	33, 33, 33, 33, 33, 33, 33, 33, 
	33, 33, 6, 19, 19, 19, 19, 19, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 19, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 20, 6, 
	16, 6, 17, 17, 17, 17, 17, 17, 
	17, 17, 17, 17, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 21, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 21, 
	6, 34, 6, 34, 6, 6, 35, 35, 
	35, 35, 35, 35, 35, 35, 35, 35, 
	6, 35, 35, 35, 35, 35, 35, 35, 
	35, 35, 35, 6, 7, 7, 7, 7, 
	7, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 7, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 8, 
	6, 6, 6, 35, 35, 35, 35, 35, 
	35, 35, 35, 35, 35, 6, 7, 7, 
	7, 7, 7, 36, 36, 36, 36, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 36, 36, 36, 36, 7, 36, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 8, 36, 37, 36, 38, 38, 38, 
	38, 38, 38, 38, 38, 38, 38, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 36, 10, 36, 36, 36, 36, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 36, 36, 36, 36, 36, 36, 36, 
	36, 36, 10, 36, 9, 9, 9, 9, 
	9, 9, 9, 9, 9, 9, 6, 39, 
	39, 39, 39, 39, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 39, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 40, 6, 6, 6, 41, 41, 
	41, 41, 41, 41, 41, 41, 41, 41, 
	6, 40, 40, 40, 40, 40, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	40, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 13, 6, 13, 14, 6, 
	42, 42, 42, 42, 42, 42, 42, 42, 
	42, 42, 6, 43, 43, 43, 43, 43, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 43, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 44, 6, 
	16, 6, 45, 45, 45, 45, 45, 45, 
	45, 45, 45, 45, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 21, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 21, 
	6, 46, 46, 46, 46, 46, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	46, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 47, 6, 47, 47, 
	47, 47, 47, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 47, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	24, 6, 24, 25, 6, 48, 48, 48, 
	48, 48, 48, 48, 48, 48, 48, 6, 
	49, 49, 49, 49, 49, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 49, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 50, 
	50, 50, 50, 50, 50, 50, 50, 50, 
	50, 6, 51, 51, 51, 51, 51, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 51, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 52, 52, 52, 52, 52, 52, 52, 
	52, 52, 52, 6, 54, 54, 54, 54, 
	54, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 54, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 55, 55, 55, 55, 55, 
	55, 55, 55, 55, 55, 53, 56, 56, 
	56, 56, 56, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 56, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 57, 53, 53, 53, 58, 58, 58, 
	58, 58, 58, 58, 58, 58, 58, 53, 
	59, 59, 59, 59, 59, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 59, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 60, 53, 60, 60, 60, 
	60, 60, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 60, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 61, 61, 61, 61, 
	61, 61, 61, 61, 61, 61, 53, 62, 
	62, 62, 62, 62, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 62, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 63, 53, 53, 53, 64, 64, 
	64, 64, 64, 64, 64, 64, 64, 64, 
	53, 65, 65, 65, 65, 65, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	65, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 66, 53, 66, 66, 
	66, 66, 66, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 66, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 67, 67, 67, 
	67, 67, 67, 67, 67, 67, 67, 53, 
	68, 68, 68, 68, 68, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 68, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	69, 53, 53, 53, 53, 53, 53, 70, 
	70, 70, 70, 70, 70, 70, 70, 70, 
	70, 53, 71, 71, 71, 71, 71, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 71, 53, 53, 53, 53, 53, 53, 
	53, 53, 72, 53, 73, 73, 73, 73, 
	73, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 73, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 74, 74, 74, 74, 74, 
	74, 74, 74, 74, 74, 53, 75, 75, 
	75, 75, 75, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 75, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 76, 53, 53, 53, 77, 77, 77, 
	77, 77, 77, 77, 77, 77, 77, 53, 
	78, 78, 78, 78, 78, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 78, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 79, 53, 79, 79, 79, 
	79, 79, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 79, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 80, 80, 80, 80, 
	80, 80, 80, 80, 80, 80, 53, 81, 
	81, 81, 81, 81, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 81, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 82, 53, 53, 53, 83, 83, 
	83, 83, 83, 83, 83, 83, 83, 83, 
	53, 84, 84, 84, 84, 84, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	84, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 85, 53, 85, 85, 
	85, 85, 85, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 85, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 86, 86, 86, 
	86, 86, 86, 86, 86, 86, 86, 53, 
	87, 87, 87, 87, 87, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 87, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 88, 53, 53, 53, 89, 
	89, 89, 89, 89, 89, 89, 89, 89, 
	89, 53, 90, 90, 90, 90, 90, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 90, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 91, 53, 91, 
	91, 91, 91, 91, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 91, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 92, 53, 92, 93, 53, 94, 94, 
	94, 94, 94, 94, 94, 94, 94, 94, 
	53, 95, 53, 96, 96, 96, 96, 96, 
	96, 96, 96, 96, 96, 53, 97, 97, 
	97, 97, 97, 97, 97, 97, 97, 97, 
	53, 98, 98, 98, 98, 98, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	98, 53, 53, 53, 53, 53, 53, 53, 
	53, 99, 53, 53, 53, 53, 53, 53, 
	97, 97, 97, 97, 97, 97, 97, 97, 
	97, 97, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 100, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 100, 53, 101, 
	101, 101, 101, 101, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 101, 53, 
	53, 53, 53, 53, 53, 53, 53, 102, 
	53, 103, 53, 103, 53, 53, 104, 104, 
	104, 104, 104, 104, 104, 104, 104, 104, 
	53, 104, 104, 104, 104, 104, 104, 104, 
	104, 104, 104, 53, 98, 98, 98, 98, 
	98, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 98, 53, 53, 53, 53, 
	53, 53, 53, 53, 99, 53, 53, 53, 
	53, 53, 53, 104, 104, 104, 104, 104, 
	104, 104, 104, 104, 104, 53, 98, 98, 
	98, 98, 98, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 98, 53, 53, 
	53, 53, 53, 53, 53, 53, 99, 53, 
	53, 53, 53, 95, 53, 96, 96, 96, 
	96, 96, 96, 96, 96, 96, 96, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 100, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 53, 53, 53, 53, 53, 53, 
	53, 53, 100, 53, 106, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 107, 105, 106, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 105, 105, 
	105, 105, 105, 105, 105, 105, 107, 105, 
	105, 105, 105, 108, 105, 110, 109, 112, 
	113, 112, 112, 114, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 112, 115, 
	115, 116, 115, 115, 115, 115, 115, 115, 
	115, 117, 115, 117, 118, 119, 120, 120, 
	120, 120, 120, 120, 120, 120, 120, 120, 
	115, 115, 115, 115, 115, 115, 115, 121, 
	121, 121, 121, 121, 121, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	122, 111, 111, 111, 111, 111, 111, 111, 
	111, 115, 115, 115, 115, 115, 115, 121, 
	121, 121, 121, 121, 121, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	122, 111, 111, 111, 111, 111, 111, 111, 
	111, 115, 115, 115, 115, 111, 6, 6, 
	6, 6, 6, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 6, 
	6, 6, 6, 6, 6, 6, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	6, 6, 6, 6, 6, 6, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	6, 6, 6, 6, 111, 112, 112, 112, 
	112, 112, 123, 123, 123, 123, 123, 123, 
	123, 123, 123, 123, 123, 123, 123, 123, 
	123, 123, 123, 123, 112, 123, 112, 113, 
	112, 112, 112, 123, 123, 123, 123, 123, 
	123, 123, 123, 123, 123, 123, 123, 123, 
	123, 123, 123, 123, 123, 112, 123, 115, 
	115, 115, 115, 115, 115, 115, 115, 115, 
	115, 115, 115, 115, 115, 115, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	115, 115, 115, 115, 115, 115, 115, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 115, 115, 115, 115, 115, 115, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 6, 
	6, 115, 115, 115, 115, 6, 115, 115, 
	115, 115, 115, 115, 115, 115, 115, 115, 
	115, 115, 115, 115, 115, 125, 125, 125, 
	125, 125, 125, 125, 125, 125, 125, 115, 
	115, 115, 115, 115, 115, 115, 125, 125, 
	125, 125, 125, 125, 124, 124, 124, 124, 
	124, 124, 124, 124, 124, 124, 124, 124, 
	124, 124, 124, 124, 124, 124, 124, 124, 
	115, 115, 115, 115, 115, 115, 125, 125, 
	125, 125, 125, 125, 124, 124, 124, 124, 
	124, 124, 124, 124, 124, 124, 124, 124, 
	124, 124, 124, 124, 124, 124, 124, 124, 
	115, 115, 115, 115, 124, 127, 127, 127, 
	127, 127, 127, 127, 127, 127, 127, 126, 
	126, 126, 126, 126, 126, 126, 127, 127, 
	127, 127, 127, 127, 126, 126, 126, 126, 
	126, 126, 126, 126, 126, 126, 126, 126, 
	126, 126, 126, 126, 126, 126, 126, 126, 
	126, 126, 126, 126, 126, 126, 127, 127, 
	127, 127, 127, 127, 126, 115, 115, 115, 
	115, 115, 115, 115, 115, 115, 115, 115, 
	115, 115, 129, 115, 38, 38, 38, 38, 
	38, 38, 38, 38, 38, 38, 115, 115, 
	115, 115, 115, 115, 115, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 115, 
	115, 115, 115, 115, 115, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 115, 
	115, 115, 115, 128, 115, 115, 115, 115, 
	115, 115, 115, 115, 115, 115, 115, 115, 
	115, 115, 115, 9, 9, 9, 9, 9, 
	9, 9, 9, 9, 9, 115, 115, 115, 
	115, 115, 115, 115, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 115, 115, 
	115, 115, 115, 115, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 115, 115, 
	115, 115, 128, 29, 29, 29, 29, 29, 
	29, 29, 29, 29, 29, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	131, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	131, 130, 31, 31, 31, 31, 31, 31, 
	31, 31, 31, 31, 130, 27, 130, 28, 
	28, 28, 28, 28, 28, 28, 28, 28, 
	28, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 131, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 130, 130, 130, 130, 
	130, 130, 130, 130, 131, 130, 115, 115, 
	115, 115, 115, 115, 115, 115, 115, 132, 
	115, 115, 115, 115, 133, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 115, 
	115, 115, 115, 115, 115, 115, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	115, 115, 115, 115, 115, 115, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	128, 128, 128, 128, 128, 128, 128, 128, 
	115, 115, 115, 115, 128, 135, 135, 135, 
	135, 135, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 135, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	136, 134, 37, 134, 137, 137, 137, 137, 
	137, 137, 137, 137, 137, 137, 134, 134, 
	134, 134, 134, 134, 134, 138, 138, 138, 
	138, 139, 138, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 138, 138, 138, 
	138, 139, 138, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 111, 141, 140, 142, 142, 
	142, 142, 142, 142, 142, 142, 142, 142, 
	140, 140, 140, 140, 140, 140, 140, 140, 
	140, 140, 140, 143, 140, 140, 140, 140, 
	140, 140, 140, 140, 140, 140, 140, 140, 
	140, 140, 140, 140, 140, 140, 140, 140, 
	140, 140, 140, 140, 140, 140, 140, 140, 
	140, 140, 140, 143, 140, 145, 145, 145, 
	145, 145, 145, 145, 145, 145, 145, 144, 
	135, 135, 135, 135, 135, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 135, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 136, 134, 37, 134, 146, 
	146, 146, 146, 146, 146, 146, 146, 146, 
	146, 134, 134, 134, 134, 134, 134, 134, 
	147, 147, 147, 147, 148, 147, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 134, 134, 
	147, 147, 147, 147, 148, 147, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 111, 135, 
	135, 135, 135, 135, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 135, 149, 
	149, 149, 149, 149, 149, 149, 149, 149, 
	149, 149, 136, 149, 37, 149, 150, 150, 
	150, 150, 150, 150, 150, 150, 150, 150, 
	149, 149, 149, 149, 149, 149, 149, 151, 
	151, 151, 151, 152, 151, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 149, 149, 149, 149, 149, 149, 151, 
	151, 151, 151, 152, 151, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 149, 149, 149, 149, 111, 135, 135, 
	135, 135, 135, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 135, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 136, 134, 37, 134, 153, 153, 153, 
	153, 153, 153, 153, 153, 153, 153, 134, 
	134, 134, 134, 134, 134, 134, 154, 154, 
	154, 154, 155, 154, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 134, 134, 154, 154, 
	154, 154, 155, 154, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 111, 135, 135, 135, 
	135, 135, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 135, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	136, 134, 37, 134, 156, 156, 156, 156, 
	156, 156, 156, 156, 156, 156, 134, 134, 
	134, 134, 134, 134, 134, 157, 157, 157, 
	157, 158, 157, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 157, 157, 157, 
	157, 158, 157, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 111, 135, 135, 135, 135, 
	135, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 135, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 6, 6, 136, 
	6, 37, 6, 159, 159, 159, 159, 159, 
	159, 159, 159, 159, 159, 6, 6, 6, 
	6, 6, 6, 6, 111, 111, 111, 111, 
	160, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 6, 6, 
	6, 6, 6, 6, 111, 111, 111, 111, 
	160, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 6, 6, 
	6, 6, 111, 6, 6, 6, 6, 6, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 34, 6, 34, 
	6, 6, 161, 161, 161, 161, 161, 161, 
	161, 161, 161, 161, 6, 6, 6, 6, 
	6, 6, 6, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 6, 6, 6, 
	6, 6, 6, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 6, 6, 6, 
	6, 111, 7, 7, 7, 7, 7, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 7, 6, 6, 6, 6, 6, 6, 
	6, 6, 6, 6, 6, 8, 6, 6, 
	6, 161, 161, 161, 161, 161, 161, 161, 
	161, 161, 161, 6, 6, 6, 6, 6, 
	6, 6, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 6, 6, 6, 6, 
	6, 6, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 6, 6, 6, 6, 
	111, 134, 134, 134, 134, 134, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	157, 157, 157, 157, 157, 157, 157, 157, 
	157, 157, 134, 134, 134, 134, 134, 134, 
	134, 157, 157, 157, 157, 157, 157, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 134, 
	134, 157, 157, 157, 157, 157, 157, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 111, 
	134, 134, 134, 134, 134, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 34, 134, 34, 134, 134, 162, 
	162, 162, 162, 162, 162, 162, 162, 162, 
	162, 134, 134, 134, 134, 134, 134, 134, 
	157, 157, 157, 157, 157, 157, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 134, 134, 
	157, 157, 157, 157, 157, 157, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 111, 134, 
	134, 134, 134, 134, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 154, 154, 
	154, 154, 154, 154, 154, 154, 154, 154, 
	134, 134, 134, 134, 134, 134, 134, 154, 
	154, 154, 154, 154, 154, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 134, 134, 134, 134, 134, 134, 154, 
	154, 154, 154, 154, 154, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 134, 134, 134, 134, 111, 134, 134, 
	134, 134, 134, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	34, 134, 34, 134, 134, 163, 163, 163, 
	163, 163, 163, 163, 163, 163, 163, 134, 
	134, 134, 134, 134, 134, 134, 154, 154, 
	154, 154, 154, 154, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 134, 134, 154, 154, 
	154, 154, 154, 154, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 111, 7, 7, 7, 
	7, 7, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 7, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	8, 134, 134, 134, 162, 162, 162, 162, 
	162, 162, 162, 162, 162, 162, 134, 134, 
	134, 134, 134, 134, 134, 157, 157, 157, 
	157, 157, 157, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 157, 157, 157, 
	157, 157, 157, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 111, 149, 149, 149, 149, 
	149, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 149, 149, 149, 149, 149, 
	149, 149, 149, 149, 149, 149, 149, 149, 
	149, 149, 149, 151, 151, 151, 151, 151, 
	151, 151, 151, 151, 151, 149, 149, 149, 
	149, 149, 149, 149, 151, 151, 151, 151, 
	151, 151, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 149, 149, 
	149, 149, 149, 149, 151, 151, 151, 151, 
	151, 151, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 149, 149, 
	149, 149, 111, 149, 149, 149, 149, 149, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 149, 149, 149, 149, 149, 149, 
	149, 149, 149, 149, 149, 34, 149, 34, 
	149, 149, 164, 164, 164, 164, 164, 164, 
	164, 164, 164, 164, 149, 149, 149, 149, 
	149, 149, 149, 151, 151, 151, 151, 151, 
	151, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 149, 149, 149, 
	149, 149, 149, 151, 151, 151, 151, 151, 
	151, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 149, 149, 149, 
	149, 111, 7, 7, 7, 7, 7, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 7, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 8, 134, 134, 
	134, 163, 163, 163, 163, 163, 163, 163, 
	163, 163, 163, 134, 134, 134, 134, 134, 
	134, 134, 154, 154, 154, 154, 154, 154, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	134, 134, 154, 154, 154, 154, 154, 154, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	111, 134, 134, 134, 134, 134, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	147, 147, 147, 147, 147, 147, 147, 147, 
	147, 147, 134, 134, 134, 134, 134, 134, 
	134, 147, 147, 147, 147, 147, 147, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 134, 
	134, 147, 147, 147, 147, 147, 147, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 111, 
	134, 134, 134, 134, 134, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 34, 134, 34, 134, 134, 165, 
	165, 165, 165, 165, 165, 165, 165, 165, 
	165, 134, 134, 134, 134, 134, 134, 134, 
	147, 147, 147, 147, 147, 147, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 134, 134, 
	147, 147, 147, 147, 147, 147, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 111, 7, 
	7, 7, 7, 7, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 7, 149, 
	149, 149, 149, 149, 149, 149, 149, 149, 
	149, 149, 8, 149, 149, 149, 164, 164, 
	164, 164, 164, 164, 164, 164, 164, 164, 
	149, 149, 149, 149, 149, 149, 149, 151, 
	151, 151, 151, 151, 151, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 149, 149, 149, 149, 149, 149, 151, 
	151, 151, 151, 151, 151, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 149, 149, 149, 149, 111, 134, 134, 
	134, 134, 134, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 138, 138, 138, 
	138, 138, 138, 138, 138, 138, 138, 134, 
	134, 134, 134, 134, 134, 134, 138, 138, 
	138, 138, 138, 138, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 134, 134, 138, 138, 
	138, 138, 138, 138, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	134, 134, 134, 134, 111, 134, 134, 134, 
	134, 134, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 134, 134, 
	134, 134, 134, 134, 134, 111, 111, 111, 
	111, 111, 111, 166, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 134, 134, 111, 111, 111, 
	111, 111, 111, 166, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 134, 
	134, 134, 134, 111, 134, 134, 134, 134, 
	134, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 134, 
	134, 134, 134, 134, 134, 134, 134, 134, 
	134, 134, 134, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 134, 134, 134, 
	134, 134, 134, 134, 111, 167, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 134, 134, 
	134, 134, 134, 134, 111, 167, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 134, 134, 
	134, 134, 111, 134, 134, 134, 134, 134, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 134, 134, 134, 134, 134, 134, 
	134, 134, 54, 134, 134, 134, 134, 134, 
	134, 134, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	134, 134, 134, 168, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 134, 134, 134, 
	134, 134, 134, 168, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 134, 134, 134, 
	134, 111, 134, 134, 134, 134, 134, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 134, 134, 134, 134, 134, 134, 134, 
	134, 73, 134, 134, 134, 134, 134, 134, 
	134, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 134, 134, 134, 134, 134, 
	134, 134, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	134, 134, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 111, 111, 111, 111, 
	111, 111, 111, 111, 134, 134, 134, 134, 
	111, 169, 169, 0
};

static const char _text_file_trans_targs[] = {
	63, 2, 69, 63, 4, 63, 63, 6, 
	7, 5, 21, 6, 7, 8, 9, 20, 
	9, 20, 10, 11, 12, 17, 11, 12, 
	13, 14, 74, 14, 74, 72, 16, 73, 
	18, 19, 22, 23, 63, 25, 24, 26, 
	27, 31, 28, 29, 30, 28, 29, 30, 
	77, 32, 31, 32, 78, 63, 33, 34, 
	35, 36, 34, 35, 36, 37, 38, 39, 
	37, 38, 39, 40, 41, 63, 40, 41, 
	63, 42, 43, 44, 45, 43, 44, 45, 
	46, 47, 48, 46, 47, 48, 49, 50, 
	51, 49, 50, 51, 52, 53, 59, 53, 
	59, 54, 55, 63, 56, 55, 63, 57, 
	58, 60, 60, 61, 102, 62, 103, 64, 
	65, 65, 66, 67, 68, 70, 71, 75, 
	76, 97, 98, 63, 63, 1, 63, 3, 
	63, 71, 63, 15, 67, 67, 63, 26, 
	27, 79, 94, 95, 63, 14, 77, 15, 
	63, 78, 80, 91, 92, 63, 81, 88, 
	89, 82, 86, 87, 83, 64, 84, 83, 
	84, 85, 85, 90, 93, 96, 99, 100, 
	101, 0
};

static const char _text_file_trans_actions[] = {
	1, 0, 2, 3, 0, 4, 5, 6, 
	6, 0, 0, 0, 0, 7, 7, 7, 
	0, 0, 0, 6, 6, 0, 0, 0, 
	7, 7, 8, 0, 9, 9, 0, 0, 
	0, 0, 0, 0, 10, 0, 0, 0, 
	0, 11, 12, 13, 13, 14, 0, 0, 
	15, 16, 14, 0, 11, 17, 0, 11, 
	16, 16, 14, 0, 0, 11, 16, 16, 
	14, 0, 0, 11, 16, 18, 14, 0, 
	19, 0, 11, 16, 16, 14, 0, 0, 
	11, 16, 16, 14, 0, 0, 11, 16, 
	16, 14, 0, 0, 7, 7, 7, 0, 
	0, 0, 6, 20, 0, 0, 21, 0, 
	0, 0, 23, 0, 24, 0, 25, 27, 
	0, 23, 0, 28, 2, 29, 29, 0, 
	30, 0, 0, 31, 32, 0, 33, 0, 
	34, 28, 35, 0, 36, 37, 38, 13, 
	13, 39, 0, 27, 40, 16, 41, 16, 
	42, 14, 43, 0, 44, 45, 39, 0, 
	27, 39, 0, 27, 46, 47, 47, 39, 
	27, 27, 47, 27, 27, 44, 0, 2, 
	2, 0
};

static const char _text_file_to_state_actions[] = {
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 22, 0, 22, 22, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0
};

static const char _text_file_from_state_actions[] = {
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 26, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0, 
	0, 0, 0, 0, 0, 0, 0, 0
};

static const short _text_file_eof_trans[] = {
	0, 1, 1, 4, 4, 7, 7, 7, 
	7, 7, 7, 7, 7, 7, 7, 7, 
	7, 7, 7, 7, 7, 7, 7, 7, 
	37, 7, 7, 7, 7, 7, 7, 7, 
	7, 54, 54, 54, 54, 54, 54, 54, 
	54, 54, 54, 54, 54, 54, 54, 54, 
	54, 54, 54, 54, 54, 54, 54, 54, 
	54, 54, 54, 54, 0, 0, 0, 0, 
	7, 124, 124, 7, 125, 127, 129, 129, 
	131, 131, 131, 129, 135, 141, 145, 135, 
	150, 135, 135, 7, 7, 7, 135, 135, 
	135, 135, 135, 150, 150, 135, 135, 135, 
	150, 135, 135, 135, 135, 135, 0, 0
};

static const int text_file_start = 63;
static const int text_file_first_final = 63;
static const int text_file_error = 0;

static const int text_file_en_multi_line_comment = 60;
static const int text_file_en_single_line_comment = 62;
static const int text_file_en_main = 63;


#line 159 "source/parser/TextFileParser.rl"

bool scanner(TextFile &text_file, const Configuration &configuration)
{
	FSM fsm_struct;
	FSM *fsm = &fsm_struct;
	fsm->ts = 0;
	fsm->te = 0;
	fsm->line = 0;
	fsm->line_start = 0;
	fsm->column = 0;
	fsm->buffer_offset = 0;
	bool parse_error = false;
	fsm->addColor = [&text_file](const Color &color){
		Color c = color;
		color_rgb_normalize(&c);
		text_file.addColor(c);
	};
	
#line 1128 "build/source/parser/TextFileParser.cpp"
	{
	 fsm->cs = text_file_start;
	 fsm->ts = 0;
	 fsm->te = 0;
	 fsm->act = 0;
	}

#line 177 "source/parser/TextFileParser.rl"
	int have = 0;
	while (1){
		char *p = fsm->buffer + have;
		int space = sizeof(fsm->buffer) - have;
		if (space == 0){
			text_file.outOfMemory();
			break;
		}
		char *eof = 0;
		auto read_size = text_file.read(fsm->buffer + have, space);
		char *pe = p + read_size;
		if (read_size > 0){
			if (read_size < sizeof(fsm->buffer)) eof = pe;
			
#line 1151 "build/source/parser/TextFileParser.cpp"
	{
	int _slen;
	int _trans;
	const char *_keys;
	const unsigned char *_inds;
	if ( p == pe )
		goto _test_eof;
	if (  fsm->cs == 0 )
		goto _out;
_resume:
	switch ( _text_file_from_state_actions[ fsm->cs] ) {
	case 26:
#line 1 "NONE"
	{ fsm->ts = p;}
	break;
#line 1167 "build/source/parser/TextFileParser.cpp"
	}

	_keys = _text_file_trans_keys + ( fsm->cs<<1);
	_inds = _text_file_indicies + _text_file_index_offsets[ fsm->cs];

	_slen = _text_file_key_spans[ fsm->cs];
	_trans = _inds[ _slen > 0 && _keys[0] <=(*p) &&
		(*p) <= _keys[1] ?
		(*p) - _keys[0] : _slen ];

_eof_trans:
	 fsm->cs = _text_file_trans_targs[_trans];

	if ( _text_file_trans_actions[_trans] == 0 )
		goto _again;

	switch ( _text_file_trans_actions[_trans] ) {
	case 14:
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
	break;
	case 16:
#line 130 "source/parser/TextFileParser.rl"
	{ fsm->numbers_i64.push_back(fsm->number_i64); }
	break;
	case 7:
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
	break;
	case 6:
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
	break;
	case 23:
#line 133 "source/parser/TextFileParser.rl"
	{ fsm->handleNewline(); }
	break;
	case 24:
#line 135 "source/parser/TextFileParser.rl"
	{ { fsm->cs = 63; goto _again;} }
	break;
	case 25:
#line 136 "source/parser/TextFileParser.rl"
	{ { fsm->cs = 63; goto _again;} }
	break;
	case 2:
#line 1 "NONE"
	{ fsm->te = p+1;}
	break;
	case 4:
#line 139 "source/parser/TextFileParser.rl"
	{ fsm->te = p+1;{ if (configuration.full_hex) fsm->colorHexFull(true); }}
	break;
	case 19:
#line 143 "source/parser/TextFileParser.rl"
	{ fsm->te = p+1;{ if (configuration.css_rgb) fsm->colorRgb(); else fsm->clearNumberStacks(); }}
	break;
	case 21:
#line 144 "source/parser/TextFileParser.rl"
	{ fsm->te = p+1;{ if (configuration.css_rgba) fsm->colorRgba(); else fsm->clearNumberStacks(); }}
	break;
	case 33:
#line 140 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.short_hex) fsm->colorHexShort(true); }}
	break;
	case 45:
#line 142 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.short_hex) fsm->colorHexShort(false); }}
	break;
	case 32:
#line 150 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.single_line_hash_comments) { fsm->cs = 62; goto _again;} }}
	break;
	case 31:
#line 151 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ }}
	break;
	case 34:
#line 152 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ }}
	break;
	case 38:
#line 153 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ }}
	break;
	case 3:
#line 140 "source/parser/TextFileParser.rl"
	{{p = (( fsm->te))-1;}{ if (configuration.short_hex) fsm->colorHexShort(true); }}
	break;
	case 1:
#line 150 "source/parser/TextFileParser.rl"
	{{p = (( fsm->te))-1;}{ if (configuration.single_line_hash_comments) { fsm->cs = 62; goto _again;} }}
	break;
	case 10:
#line 152 "source/parser/TextFileParser.rl"
	{{p = (( fsm->te))-1;}{ }}
	break;
	case 17:
#line 153 "source/parser/TextFileParser.rl"
	{{p = (( fsm->te))-1;}{ }}
	break;
	case 5:
#line 1 "NONE"
	{	switch(  fsm->act ) {
	case 3:
	{{p = (( fsm->te))-1;} if (configuration.full_hex) fsm->colorHexFull(false); }
	break;
	case 4:
	{{p = (( fsm->te))-1;} if (configuration.short_hex) fsm->colorHexShort(false); }
	break;
	case 7:
	{{p = (( fsm->te))-1;} if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
	break;
	case 9:
	{{p = (( fsm->te))-1;} if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
	break;
	case 10:
	{{p = (( fsm->te))-1;} if (configuration.single_line_c_comments) { fsm->cs = 62; goto _again;} }
	break;
	case 11:
	{{p = (( fsm->te))-1;}  if (configuration.multi_line_c_comments) { fsm->cs = 60; goto _again;} }
	break;
	case 14:
	{{p = (( fsm->te))-1;} }
	break;
	case 15:
	{{p = (( fsm->te))-1;} }
	break;
	}
	}
	break;
	case 11:
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = 0; }
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
	break;
	case 13:
#line 130 "source/parser/TextFileParser.rl"
	{ fsm->numbers_i64.push_back(fsm->number_i64); }
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
	break;
	case 18:
#line 130 "source/parser/TextFileParser.rl"
	{ fsm->numbers_i64.push_back(fsm->number_i64); }
#line 143 "source/parser/TextFileParser.rl"
	{ fsm->te = p+1;{ if (configuration.css_rgb) fsm->colorRgb(); else fsm->clearNumberStacks(); }}
	break;
	case 42:
#line 130 "source/parser/TextFileParser.rl"
	{ fsm->numbers_i64.push_back(fsm->number_i64); }
#line 146 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }}
	break;
	case 20:
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
#line 144 "source/parser/TextFileParser.rl"
	{ fsm->te = p+1;{ if (configuration.css_rgba) fsm->colorRgba(); else fsm->clearNumberStacks(); }}
	break;
	case 35:
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
#line 147 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }}
	break;
	case 47:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 141 "source/parser/TextFileParser.rl"
	{ fsm->act = 3;}
	break;
	case 44:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 142 "source/parser/TextFileParser.rl"
	{ fsm->act = 4;}
	break;
	case 9:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 147 "source/parser/TextFileParser.rl"
	{ fsm->act = 9;}
	break;
	case 37:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 148 "source/parser/TextFileParser.rl"
	{ fsm->act = 10;}
	break;
	case 36:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 149 "source/parser/TextFileParser.rl"
	{ fsm->act = 11;}
	break;
	case 28:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 152 "source/parser/TextFileParser.rl"
	{ fsm->act = 14;}
	break;
	case 27:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 153 "source/parser/TextFileParser.rl"
	{ fsm->act = 15;}
	break;
	case 12:
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = 0; }
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
	break;
	case 40:
#line 130 "source/parser/TextFileParser.rl"
	{ fsm->numbers_i64.push_back(fsm->number_i64); }
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
#line 145 "source/parser/TextFileParser.rl"
	{ fsm->te = p;p--;{ if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }}
	break;
	case 41:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
#line 145 "source/parser/TextFileParser.rl"
	{ fsm->act = 7;}
	break;
	case 39:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
#line 153 "source/parser/TextFileParser.rl"
	{ fsm->act = 15;}
	break;
	case 8:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
#line 147 "source/parser/TextFileParser.rl"
	{ fsm->act = 9;}
	break;
	case 29:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
#line 152 "source/parser/TextFileParser.rl"
	{ fsm->act = 14;}
	break;
	case 46:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 141 "source/parser/TextFileParser.rl"
	{ fsm->act = 3;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
	break;
	case 43:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 142 "source/parser/TextFileParser.rl"
	{ fsm->act = 4;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
	break;
	case 30:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = 0; }
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
#line 153 "source/parser/TextFileParser.rl"
	{ fsm->act = 15;}
	break;
	case 15:
#line 1 "NONE"
	{ fsm->te = p+1;}
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = 0; }
#line 127 "source/parser/TextFileParser.rl"
	{ fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
#line 145 "source/parser/TextFileParser.rl"
	{ fsm->act = 7;}
#line 131 "source/parser/TextFileParser.rl"
	{ fsm->number_double_start = p; }
	break;
#line 1465 "build/source/parser/TextFileParser.cpp"
	}

_again:
	switch ( _text_file_to_state_actions[ fsm->cs] ) {
	case 22:
#line 1 "NONE"
	{ fsm->ts = 0;}
	break;
#line 1474 "build/source/parser/TextFileParser.cpp"
	}

	if (  fsm->cs == 0 )
		goto _out;
	if ( ++p != pe )
		goto _resume;
	_test_eof: {}
	if ( p == eof )
	{
	if ( _text_file_eof_trans[ fsm->cs] > 0 ) {
		_trans = _text_file_eof_trans[ fsm->cs] - 1;
		goto _eof_trans;
	}
	}

	_out: {}
	}

#line 191 "source/parser/TextFileParser.rl"
			if (fsm->cs == text_file_error) {
				parse_error = true;
				text_file.syntaxError(fsm->line, fsm->ts - fsm->buffer - fsm->line_start, fsm->line, fsm->te - fsm->buffer - fsm->line_start);
				break;
			}
			if (fsm->ts == 0){
				have = 0;
				fsm->line_start -= sizeof(fsm->buffer);
			}else{
				have = pe - fsm->ts;
				memmove(fsm->buffer, fsm->ts, have);
				int buffer_movement = fsm->ts - fsm->buffer;
				fsm->te -= buffer_movement;
				fsm->line_start -= buffer_movement;
				fsm->ts = fsm->buffer;
				fsm->buffer_offset += fsm->ts - fsm->buffer;
			}
		}else{
			break;
		}
	}
	return parse_error == false;
}

}
